@@ -2,9 +2,7 @@
 # Bioconvert is a project to facilitate the interconversion               #
 # of life science data from one format to another.                        #
 #                                                                         #
-# Authors: see CONTRIBUTORS.rst                                           #
-# Copyright © 2018  Institut Pasteur, Paris and CNRS.                     #
-# See the COPYRIGHT file for details                                      #
+# Copyright © 2018-2022  Institut Pasteur, Paris and CNRS.                #
 #                                                                         #
 # bioconvert is free software: you can redistribute it and/or modify      #
 # it under the terms of the GNU General Public License as published by    #
@@ -19,12 +17,14 @@
 # You should have received a copy of the GNU General Public License       #
 # along with this program (COPYING file).                                 #
 # If not, see <http://www.gnu.org/licenses/>.                             #
+#                                                                         #
+# Repository: https://github.com/bioconvert/bioconvert                    #
+# Documentation: http://bioconvert.readthedocs.io                         #
 ###########################################################################
 """Convert :term:`FASTQ` to :term:`QUAL` format"""
 from bioconvert import ConvBase, bioconvert_script, logger
 from bioconvert.core.base import ConvArg
-from bioconvert.core.decorators import (compressor, in_gz, out_compressor,
-                                        requires, requires_nothing)
+from bioconvert.core.decorators import compressor, in_gz, out_compressor, requires, requires_nothing
 
 logger.__name__ = "fastq2qual"
 
